:mod:`kwant.continuum` -- Tools for continuum systems
=====================================================

.. module:: kwant.continuum

Discretizer
-----------
.. autosummary::
    :toctree: generated/

    discretize
    discretize_symbolic
    build_discretized

Symbolic helpers
----------------
.. autosummary::
    :toctree: generated/

    sympify
    lambdify
